package com.xinelu.manage.mapper.basenursinginfo;

import com.xinelu.manage.domain.basenursinginfo.BaseNursingInfo;

import java.util.List;

/**
 * 护理知识库Mapper接口
 *
 * @author xinelu
 * @date 2024-05-17
 */
public interface BaseNursingInfoMapper {
    /**
     * 查询护理知识库
     *
     * @param id 护理知识库主键
     * @return 护理知识库
     */
    BaseNursingInfo selectBaseNursingInfoById(Long id);

    /**
     * 查询护理知识库列表
     *
     * @param baseNursingInfo 护理知识库
     * @return 护理知识库集合
     */
    List<BaseNursingInfo> selectBaseNursingInfoList(BaseNursingInfo baseNursingInfo);

    /**
     * 新增护理知识库
     *
     * @param baseNursingInfo 护理知识库
     * @return 结果
     */
    int insertBaseNursingInfo(BaseNursingInfo baseNursingInfo);

    /**
     * 修改护理知识库
     *
     * @param baseNursingInfo 护理知识库
     * @return 结果
     */
    int updateBaseNursingInfo(BaseNursingInfo baseNursingInfo);

    /**
     * 删除护理知识库
     *
     * @param id 护理知识库主键
     * @return 结果
     */
    int deleteBaseNursingInfoById(Long id);

    /**
     * 批量删除护理知识库
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteBaseNursingInfoByIds(Long[] ids);
}
